@@ -169,8 +169,17 @@ void LXQtPlatformTheme::loadSettings() {
         if (baseColor_.isValid())
         {
             LXQtPalette_->setColor(QPalette::Base, baseColor_);
-            // See Qt -> qpalette.cpp -> qt_fusionPalette()
-            LXQtPalette_->setColor(QPalette::Disabled, QPalette::Base, winColor_);
+            // Qt makes the alternate base color (used by some item views) by mixing the button
+            // color (= window color) and base color. That can result in unreadable texts when
+            // the base and window colors have a high contrast with each other.
+            color = baseColor_;
+            int l = color.lightness();
+            if (l < 127)
+                l += 10;
+            else
+                l -= 10;
+            color.setHsl(color.hue(), color.saturation(), l);
+            LXQtPalette_->setColor(QPalette::AlternateBase, color);
         }
         if (highlightColor_.isValid())
         {
@@ -458,10 +467,8 @@ QVariant LXQtPlatformTheme::themeHint(ThemeHint hint) const {
         break;
     case WheelScrollLines:
         return wheelScrollLines_;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     case QPlatformTheme::ShowShortcutsInContextMenus:
         return QVariant(true);
-#endif
     default:
         break;
     }
@@ -495,11 +502,7 @@ QStringList LXQtPlatformTheme::xdgIconThemePaths() const
     xdgDirs.append(xdgDataDirs);
 
     for (const auto &s: xdgDirs) {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
         const QStringList r = s.split(QLatin1Char(':'), Qt::SkipEmptyParts);
-#else
-        const QStringList r = s.split(QLatin1Char(':'), QString::SkipEmptyParts);
-#endif
         for (const auto& xdgDir: r) {
             const QFileInfo xdgIconsDir(xdgDir + QStringLiteral("/icons"));
             if (xdgIconsDir.isDir())
