@@ -43,6 +43,7 @@ class StatusNotifierItem : public QObject
 {
     Q_OBJECT
 
+    Q_PROPERTY(QString Category READ category)
     Q_PROPERTY(QString Title READ title)
     Q_PROPERTY(QString Id READ id)
     Q_PROPERTY(QString Status READ status)
@@ -61,7 +62,7 @@ class StatusNotifierItem : public QObject
 
 public:
     StatusNotifierItem(QString id, QObject *parent = nullptr);
-    ~StatusNotifierItem();
+    ~StatusNotifierItem() override;
 
     QString id() const
     { return mId; }
@@ -74,6 +75,10 @@ public:
     { return mStatus; }
     void setStatus(const QString &status);
 
+    QString category() const
+    { return mCategory; }
+    void setCategory(const QString &category);
+
     QDBusObjectPath menu() const
     { return mMenuPath; }
     void setMenuPath(const QString &path);
@@ -162,6 +167,7 @@ private:
     QString mId;
     QString mTitle;
     QString mStatus;
+    QString mCategory;
 
     // icons
     QString mIconName, mOverlayIconName, mAttentionIconName;
